@@ -5,7 +5,7 @@
  * pgpool: a language independent connection pool server for PostgreSQL
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2022	PgPool Global Development Group
+ * Copyright (c) 2003-2018	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -337,10 +337,17 @@ main(int argc, char **argv)
 		char		dirnamebuf[POOLMAXPATHLEN + 1];
 		char	   *dirp;
 
-		strlcpy(dirnamebuf, conf_file, sizeof(dirnamebuf));
-		dirp = dirname(dirnamebuf);
-		snprintf(pool_passwd, sizeof(pool_passwd), "%s/%s",
-				 dirp, pool_config->pool_passwd);
+		if (pool_config->pool_passwd[0] != '/')
+		{
+			strlcpy(dirnamebuf, conf_file, sizeof(dirnamebuf));
+			dirp = dirname(dirnamebuf);
+			snprintf(pool_passwd, sizeof(pool_passwd), "%s/%s",
+					 dirp, pool_config->pool_passwd);
+		}
+		else
+			strlcpy(pool_passwd, pool_config->pool_passwd,
+				 sizeof(pool_passwd));
+
 		pool_init_pool_passwd(pool_passwd, POOL_PASSWD_R);
 	}
 
@@ -515,31 +522,19 @@ stop_me(void)
 				(errmsg("could not read pid file")));
 	}
 
-	for (;;)
+	if (kill(pid, stop_sig) == -1)
 	{
-		int		cnt = 5;	/* sending sinal retry interval */
+		ereport(FATAL,
+				(errmsg("could not stop process with pid: %d", pid),
+				 errdetail("%m")));
+	}
+	ereport(LOG,
+			(errmsg("stop request sent to pgpool. waiting for termination...")));
 
-		if (kill(pid, stop_sig) == -1)
-		{
-			ereport(FATAL,
-					(errmsg("could not stop process with pid: %d", pid),
-					 errdetail("%m")));
-		}
-		ereport(LOG,
-				(errmsg("stop request sent to pgpool (pid: %d). waiting for termination...", pid)));
-
-		while (kill(pid, 0) == 0)
-		{
-			fprintf(stderr, ".");
-			sleep(1);
-			cnt--;
-			/* If pgpool did not stop within 5 seconds, break the loop and try
-			 * to send the signal again */
-			if (cnt <= 0)
-				break;
-		}
-		if (cnt > 0)
-			break;
+	while (kill(pid, 0) == 0)
+	{
+		fprintf(stderr, ".");
+		sleep(1);
 	}
 	fprintf(stderr, "done.\n");
 	pid_file = get_pid_file_path();
